@@ -91,7 +91,10 @@ class CapturedException(object):
         -------
         str
         """
-        return self.name + '(' + self.message + ')'
+        s = self.name + '(' + self.message + ')'
+        if exc_cause := getattr(self.tb, '__cause__', None):
+            s += f' -caused by- {format_exception_with_cause(exc_cause)}'
+        return s
 
     def format_with_cause(self):
         """Returns a representation of the original exception including the
@@ -153,13 +156,6 @@ def format_oneline_tb(exc, tb=None, limit=None, include_str=True):
     # startup.
     from datalad import cfg
 
-    if include_str:
-        # try exc message else exception type
-        leading = exc.message or exc.name
-        out = "{} ".format(leading)
-    else:
-        out = ""
-
     if tb is None:
         tb = traceback.TracebackException.from_exception(
             exc,
@@ -168,6 +164,15 @@ def format_oneline_tb(exc, tb=None, limit=None, include_str=True):
             capture_locals=False,
         )
 
+    if include_str:
+        # try exc message else exception type
+        leading = exc.message or exc.name
+        out = "{} ".format(leading)
+        if exc_cause := getattr(tb, '__cause__', None):
+            out += f'-caused by- {format_exception_with_cause(exc_cause)} '
+    else:
+        out = ""
+
     entries = []
     entries.extend(tb.stack)
     if tb.__cause__:
