@@ -14,20 +14,23 @@ __docformat__ = 'restructuredtext'
 
 import concurrent.futures
 import inspect
+import logging
 import sys
 import time
 import uuid
-
 from collections import defaultdict
-from queue import Queue, Empty
+from queue import (
+    Empty,
+    Queue,
+)
 from threading import Thread
 
-from . import ansi_colors as colors
-from ..log import log_progress
-from ..utils import path_is_subpath
 from datalad.support.exceptions import CapturedException
 
-import logging
+from ..log import log_progress
+from ..utils import path_is_subpath
+from . import ansi_colors as colors
+
 lgr = logging.getLogger('datalad.parallel')
 
 
@@ -86,8 +89,6 @@ class ProducerConsumer:
     -----
     - with jobs > 1, results are yielded as soon as available, so order
       might not match the one provided by "producer".
-    - jobs > 1, is "effective" only for Python >= 3.8.  For older versions it
-      would log a warning (upon initial encounter) if jobs > 1 is specified.
     - `producer` must produce unique entries. AssertionError might be raised if
       the same entry is to be consumed.
     - `consumer` can add to the queue of items produced by producer via
@@ -250,6 +251,7 @@ class ProducerConsumer:
         """
         if jobs in (None, "auto"):
             from datalad import cfg
+
             # ATM there is no "auto" for this operation, so in both auto and None
             # just consult max-jobs which can only be an int ATM.
             # "auto" could be for some auto-scaling based on a single future time
